{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Bisulfite QC tools",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/QCannotation"
                },
                {
                    "type": "File",
                    "id": "#main/bam"
                },
                {
                    "type": "string",
                    "default": "bisulfite_QC",
                    "id": "#main/output_dir"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bisulfite_qc_conversion.cwl",
                    "in": [
                        {
                            "source": "#main/QCannotation",
                            "id": "#main/bisulfite_conversion/QCannotation"
                        },
                        {
                            "source": "#main/bam",
                            "id": "#main/bisulfite_conversion/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bisulfite_conversion/reference"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/bisulfite_conversion/vcf"
                        }
                    ],
                    "out": [
                        "#main/bisulfite_conversion/base_convertion",
                        "#main/bisulfite_conversion/read_convertion",
                        "#main/bisulfite_conversion/cph_retention",
                        "#main/bisulfite_conversion/cpg_retention"
                    ],
                    "id": "#main/bisulfite_conversion"
                },
                {
                    "run": "#bisulfite_qc_coverage_stats.cwl",
                    "in": [
                        {
                            "source": "#main/QCannotation",
                            "id": "#main/coverage_stats/QCannotation"
                        },
                        {
                            "source": "#main/bam",
                            "id": "#main/coverage_stats/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/coverage_stats/reference"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/coverage_stats/vcf"
                        }
                    ],
                    "out": [
                        "#main/coverage_stats/bga_bed",
                        "#main/coverage_stats/cov_dist",
                        "#main/coverage_stats/bga_bed_dup",
                        "#main/coverage_stats/dup_report",
                        "#main/coverage_stats/cpg_bed",
                        "#main/coverage_stats/cov_dist_cpg",
                        "#main/coverage_stats/cpg_dist"
                    ],
                    "id": "#main/coverage_stats"
                },
                {
                    "run": "#bisulfite_qc_cpg_retention_distribution.cwl",
                    "in": [
                        {
                            "source": "#main/QCannotation",
                            "id": "#main/cpg_retention_distribution/QCannotation"
                        },
                        {
                            "source": "#main/bam",
                            "id": "#main/cpg_retention_distribution/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/cpg_retention_distribution/reference"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/cpg_retention_distribution/vcf"
                        }
                    ],
                    "out": [
                        "#main/cpg_retention_distribution/cpg_retention_dist"
                    ],
                    "id": "#main/cpg_retention_distribution"
                },
                {
                    "run": "#gather_to_sub_directory.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/bisulfite_conversion/base_convertion",
                                "#main/bisulfite_conversion/read_convertion",
                                "#main/bisulfite_conversion/cph_retention",
                                "#main/bisulfite_conversion/cpg_retention",
                                "#main/mapping_summary/strand_table",
                                "#main/mapping_summary/mapping_quality",
                                "#main/cpg_retention_distribution/cpg_retention_dist",
                                "#main/coverage_stats/bga_bed",
                                "#main/coverage_stats/cov_dist",
                                "#main/coverage_stats/bga_bed_dup",
                                "#main/coverage_stats/dup_report",
                                "#main/coverage_stats/cpg_bed",
                                "#main/coverage_stats/cov_dist_cpg",
                                "#main/coverage_stats/cpg_dist"
                            ],
                            "id": "#main/gather_to_sub_directory/files"
                        },
                        {
                            "source": "#main/output_dir",
                            "id": "#main/gather_to_sub_directory/outdir"
                        }
                    ],
                    "out": [
                        "#main/gather_to_sub_directory/gathered_directory"
                    ],
                    "id": "#main/gather_to_sub_directory"
                },
                {
                    "run": "#bisulfite_qc_mapping_summary.cwl",
                    "in": [
                        {
                            "source": "#main/QCannotation",
                            "id": "#main/mapping_summary/QCannotation"
                        },
                        {
                            "source": "#main/bam",
                            "id": "#main/mapping_summary/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/mapping_summary/reference"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/mapping_summary/vcf"
                        }
                    ],
                    "out": [
                        "#main/mapping_summary/strand_table",
                        "#main/mapping_summary/mapping_quality"
                    ],
                    "id": "#main/mapping_summary"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/gather_to_sub_directory/gathered_directory",
                    "id": "#main/QC_directory"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: Bisulfite conversion rate.",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_bisulfiteconversion.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 20000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_conversion.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_conversion.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_conversion.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_conversion.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "totalBaseConversionRate.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/base_convertion"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "CpGRetentionByReadPos.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/cpg_retention"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "CpHRetentionByReadPos.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/cph_retention"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "totalReadConversionRate.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/read_convertion"
                }
            ],
            "id": "#bisulfite_qc_conversion.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: Bisulfite conversion rate.",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_Coveragestats.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 20000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bga.bed"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/bga_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bga_dup.bed"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/bga_bed_dup"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "covdist_table.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cov_dist"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "covdist_cpg_table.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cov_dist_cpg"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cpg.bed"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cpg_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cpg_dist_table.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cpg_dist"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "dup_report.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/dup_report"
                }
            ],
            "id": "#bisulfite_qc_coverage_stats.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: CpG Retention Distribution",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_CpGretentiondistribution.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "CpGRetentionDist.txt"
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/cpg_retention_dist"
                }
            ],
            "id": "#bisulfite_qc_cpg_retention_distribution.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: Bisulfite conversion rate.",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_mappingsummary.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_table.txt"
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/mapping_quality"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "strand_table.txt"
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/strand_table"
                }
            ],
            "id": "#bisulfite_qc_mapping_summary.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "directory_gatherer.sh"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "directory_gatherer.sh",
                            "entry": "set -eou pipefail\n\noutdir=\"$1\"\nfiles=\"${@:2}\"\nmkdir $outdir\nchmod -R 777 $outdir\ncp -t $outdir $files\n\nexit 0\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gather_to_sub_directory.cwl/files"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gather_to_sub_directory.cwl/outdir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.outdir)"
                    },
                    "id": "#gather_to_sub_directory.cwl/gathered_directory"
                }
            ],
            "id": "#gather_to_sub_directory.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
